%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                 Curve fitting of PCP-SILAC Data 
%                                  Created by Anders Kristensen, modified by Nichollas Scott
%                                                       Foster lab,UBC, 2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% N.B Ensure the OutputGaus and Output_Chromatograms output files are empty
% before running this script, if these folders contain files from previous
% Gaus filtering these will be incorportated into the final output and can
% be very confusing

%% Current Version: 2.0

tic
%prepare matlab for analysis
clear all;
matlabpool close force local
matlabpool;

%create dictories for script
mkdir('MvsL');
mkdir('HvsL');

%Import data both MvsL, HvsL and MvsL (Import all files to ensure uniform processing)
[num_val_MvsL,txt_MvsL] = xlsread('MvsL_Protein_groups_reverse_containmates_removed_for_script.xlsx'); %Import file MvsL
[num_val_HvsL,txt_HvsL] = xlsread('HvsL_Protein_groups_reverse_containmates_removed_for_script.xlsx'); %Import file HvsL
[SEC_size_alignment]=xlsread('SEC_alignment.xlsx');
%Dimension of arrays
Dimension_of_PCP_SILAC=size(num_val_MvsL);
Proteins=Dimension_of_PCP_SILAC(1);
Fractions=Dimension_of_PCP_SILAC(2);

% Variable used in script
Ite = 500;                          % Number of iterations in crossvalidation
Start_Fr= 2;                        % The first fraction to be analyzed
End_Fr =47;                         % The last fraction to be analyzed
Number_of_experimental_channels=2;  % Defines the number of experiments to be compared
Protein_number=1:Proteins;

% Note: A problem has been noted when this script using matlab 2012a on a 
%mac with excel 2011 for mac. The resulting imported data may lack gene 
%names that are numbers, to overcome this the following bit of code was 
%written to replace the missing data with the correct name

%for i=1:Proteins_raw
    %if (~isnan(num_val_raw(i,1)))==1
        %txt_raw{i+1,1}=num2str(num_val_raw(i,1));
    %end
%end

%Create Size calibration curve based on Start and end fraction
SEC_fit=polyfit(SEC_size_alignment(1,:),SEC_size_alignment(2,:),1);
  
%Define the experiment to be processed
for Experimental_channel_loop=1:Number_of_experimental_channels
    
    % Allocate variables
    No_Quant_String= zeros(1,Proteins);
    No_After_adding_one_missing_data= zeros(1,Proteins);
    No_After_filtering=zeros(1,Proteins);
    No_Gaus=zeros(1,Proteins);
    Try_Fit=zeros(1,Proteins);
    Gaussians_used_in_analysis_counter=zeros(1,Proteins);
    Gaussians_excluded_from_analysis_counter=zeros(1,Proteins);

    if Experimental_channel_loop ==1
        cd('MvsL');
        mkdir('OutputGaus')
        mkdir('Output_Chromatograms');
        mkdir('OutputGaus_filtered_out');
        mkdir('Output_Chromatograms_filtered_out');
        mkdir('Error_check');
        
        Experimental_channel = 'MvsL' % define the MvsL
        num_val_to_test=num_val_MvsL; % call data file for MvsL
        
    elseif Experimental_channel_loop == 2 
        cd('HvsL');
        mkdir('OutputGaus')
        mkdir('Output_Chromatograms');
        mkdir('OutputGaus_filtered_out');
        mkdir('Output_Chromatograms_filtered_out');
        mkdir('Error_check');
        
        Experimental_channel = 'HvsL' % define the MvsL
        num_val_to_test=num_val_HvsL; % call data file for HvsL
        
    end
%Loop to analyze raw data
parfor Prot_nr = 1:Proteins
    AK= num_val_to_test(Prot_nr,2:Fractions);
    
try  
%% Replace one missing value with mean of nabours
    %Define variable
    Count =numel(AK);
    AK2= isnan(AK);
    Output_mean=zeros(1,Count); %Allocate Output_mean
    
    %Find number of quantitations events
    No_Quant_String(1,Prot_nr)=length(find(AK2==0)); 
    
    %find NaN values flanked by numbers
    for i=2:(Count-1)   %count -1 disreagards the value in the 55 position
        if 1==isnan(AK(i))
                Test1=AK2((i-1):(i+1));
                    if  1==isequal(~Test1,[1 0 1])
                        Number=AK((i-1):(i+1));
                        Number2 = Number(~Test1);
                        miss = mean(Number2); %average if  data point is missing
                    else
                        miss=0;
                    end
                Output_mean(1,i) = miss;
            else
                Output_mean(1,i) = AK(i);              
        end
    end
    
    %Fill in count position with number in AK or zero
    %fill in first postion
    if isnan(AK(1))
    Output_mean(1,1)=0;
    else
    Output_mean(1,1)=AK(1);
    end
    
    
    %fill in last postion
    if isnan(AK(Count))
    Output_mean(1,Count)=0;
    else
    Output_mean(1,Count)=AK(Count);
    end
    
    %Find number of quantitations events    
    No_After_adding_one_missing_data(1,Prot_nr)=length(find((Output_mean>0)==1)); 

    %% Minimum quantitation value, removes values below 0.2 to NaN, if
    %% mixing has been done incorrect can change this to lower value but
    %% not ideal
    Filter = Output_mean;
    Filter(Filter<0.2) = NaN; 
         
    %create variable with to test fitting against 
    missing_value_fixed = Filter;
    
   
    %% Consecutive numbers, if less then 5 consecutive number removes
    %% chromogram and replace with 0.05
    Multi_NaN = NaN(1,10);
    Sig=[Multi_NaN Filter Multi_NaN];
    AKK= ~(isnan(Sig));
    Count2= numel(Sig);
 
    Sig2=zeros(1,Count2); %Allocate variable  
    for i= 11:(Count2-10)  
        if 5== sum(AKK((i-(4)):i));
        Sig2(1,i) = Sig(i);
        elseif 5== sum(AKK((i-(3)):(i+1)));
        Sig2(1,i) = Sig(i);
        elseif 5== sum(AKK((i-(2)):(i+2)));
        Sig2(1,i) = Sig(i);
        elseif 5== sum(AKK((i-(1)):(i+3)));
        Sig2(1,i) = Sig(i);
        elseif 5== sum(AKK((i):(i+4)));
        Sig2(1,i) = Sig(i);
        else Sig2(1,i) = 0.05;
        end
    
    end
    Out= Sig2(1,((5+1):(Count2-5)));
    No_After_filtering(1,Prot_nr)=length(find((Out>0.05)==1));
    
     %% Smooth data, change vary the number of data points used for smoothing
    Smo_Out= (smooth(Out,4))';
   
    %At least five datapoints
    if length(find((Smo_Out>0.05)==1))<5
    else
        %% Gausian new
        Try_Fit(1,Prot_nr)=1;
        %Input
        AK= Smo_Out;
        mH= max(AK); %max height
        y = AK';
        x = (1:numel(y))';
        %N = length(x);
       
        ok_ = isfinite(x) & isfinite(y);
        if ~all( ok_ )
        warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
        end
       
        x2 = x(ok_);
        y2 = y(ok_);
        N2 = length(x2);

        %Define start site for peak fitting, finds a maximum of 6 peaks,
        %uses this data to define the x fraction to look for curves based off the
        %maximum
        N6= sort(findpeaks(y2,'NPEAKS', 6),'descend');
        if isempty(N6)      %In case two equal points of maximum peak
            N6=max(y2);           
            N7= length(find(y2==N6));
            N8= find(y2==N6);
            N3=zeros(1,5);
            for i=1:N7
                N3(1,i)=N8(i);       
            end           
        else       
            N7= length(N6);
            N3=zeros(1,5);
            for i=1:N7
                try
                N3(1,i)=find(y2==N6(i));  % will give error if by chance two numbers in the row are the same as the maximum
                catch %work out which one of the value is a real maxmium within y2
                error_check=length(find(y2==N6(i)));
                error_matrix=zeros(1,error_check);
                error_matrix=find(y2==N6(i));
                for ii=1:error_check
                if y2(error_matrix(ii))>y2(error_matrix(ii)+1)...
                & y2(error_matrix(ii))>y2(error_matrix(ii)-1);
                N3(1,i)=error_matrix(ii);
                break
                else N3(1,i)=error_matrix(ii);    %if cant find the condition where one of the error_matrix values is maximum then discard the value
                end
                end
                end
        end

        N5=zeros(1,5);
        for i=1:5
            if N3(1,i)==0;
                N4= random('Normal',N3(1),2);
            else N4=N3(1,i);
            end
            N5(1,i)= N4;
        end


        %Parameters for fitting
        field1='a';  value1 = [N6(1) N5(1) 2];
        field2='b';  value2 = [N6(1) N5(1) 2 mH N5(2) 2];
        field3='c';  value3 = [N6(1) N5(1) 2 mH N5(2) 2 mH N5(3) 2];
        field4='d';  value4 = [N6(1) N5(1) 2 mH N5(2) 2 mH N5(3) 2 mH N5(4) 2];
        field5='e';  value5 = [N6(1) N5(1) 2 mH N5(2) 2 mH N5(3) 2 mH N5(4) 2 mH N5(5) 2];
       
        st=struct(field1,value1,field2,value2,field3,value3,field4,value4,field5,value5);

        %Fitoption, note can modify the lower limits, number in [] correspond to centre hight and width
        field6='a';  value6 = fitoptions('method','NonlinearLeastSquares','Robust','off','Lower',[0.1 0.1 0.1]);
        field7='b';  value7 = fitoptions('method','NonlinearLeastSquares','Robust','off','Lower',[0.1 0.1 0.1 0.1 0.1 0.1]);
        field8='c';  value8 = fitoptions('method','NonlinearLeastSquares','Robust','off','Lower',[0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1]);
        field9='d';  value9 = fitoptions('method','NonlinearLeastSquares','Robust','off','Lower',[0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1]);
        field10='e'; value10 = fitoptions('method','NonlinearLeastSquares','Robust','off','Lower',[0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1]);
       
        fo=struct(field6,value6,field7,value7,field8,value8,field9,value9,field10,value10);
       
        %Fittype
        field11='a';  value11 = fittype('gauss1');
        field12='b';  value12 = fittype('gauss2');
        field13='c';  value13 = fittype('gauss3');
        field14='d';  value14 = fittype('gauss4');
        field15='e';  value15 = fittype('gauss5');
       
        ft=struct(field11,value11,field12,value12,field13,value13,field14,value14,field15,value15);
       
        %Output_SSE
        field16='a';  value16 = zeros(1,Ite);
        field17='b';  value17 = zeros(1,Ite);
        field18='c';  value18 = zeros(1,Ite);
        field19='d';  value19 = zeros(1,Ite);
        field20='e';  value20 = zeros(1,Ite);
       
        Output_SSE=struct(field16,value16,field17,value17,field18,value18,field19,value19,field20,value20);
        % Fitting using crossvalidation, done via leave one out analysis
        % where 10% of the curve is removed to check
        fn = fieldnames(ft);

        for ii=1:5
        i=1;
        ready = false;
        while ~ready
            try %attempt the hold out analysis
                i=i+1;
                [train,test] = crossvalind('HoldOut',N2, 0.1);
                set(fo.(fn{ii}),'Startpoint',st.(fn{ii}));
                curveFit = fit(x2(train(ok_)),y2(train(ok_)),ft.(fn{ii}),fo.(fn{ii}));
                yhat = feval(curveFit,x2);
                Output_SSE.(fn{ii})(1,i) =  sum((yhat - y2).^2);
                ready = (i >= Ite);
            catch
            %if the crossvalidation process leads to an error repeat till 
            %the required successful initrations have been done   
            if i>1 % this ensures  i = 1 will not be turned to 0
               i=i-1
            end
            end
        end
        end


        %Gausian using all points, evaluate 1 to 5 gaussians, if the data
        %can not be fit set curvefit, goodness and probes to vlaue which
        %will be discarded
        
        % dummy_gaussian
            dummy_x2= [1:1:65]';
            dummy_y2= ones(1,65)';

        % test real data   
        try
        set(fo.a,'Startpoint',st.a);       
        [curveFit1,goodness1,probs1] = fit(x2,y2,ft.a,fo.a);
        catch
            %Use dummy values
            set(fo.a,'Startpoint',st.a);
            [curveFit1,goodness1,probs1] = fit(dummy_x2,dummy_y2,ft.a,fo.a);
        end
        
        try
        set(fo.b,'Startpoint',st.b);       
        [curveFit2,goodness2,probs2] = fit(x2,y2,ft.b,fo.b);
        catch
            %Use dummy values    
            set(fo.b,'Startpoint',st.b);       
            [curveFit2,goodness2,probs2] = fit(dummy_x2,dummy_y2,ft.b,fo.b);
        end
        
        try
        set(fo.c,'Startpoint',st.c);       
        [curveFit3,goodness3,probs3] = fit(x2,y2,ft.c,fo.c);
        catch
            
             %Use dummy values 
             set(fo.c,'Startpoint',st.c);       
             [curveFit3,goodness3,probs3] = fit(dummy_x2,dummy_y2,ft.c,fo.c);
        end
        
        try
        set(fo.d,'Startpoint',st.d);       
        [curveFit4,goodness4,probs4] = fit(x2,y2,ft.d,fo.d);
        catch
            
            %Use dummy values 
            set(fo.d,'Startpoint',st.d);       
            [curveFit4,goodness4,probs4] = fit(dummy_x2,dummy_y2,ft.d,fo.d);
        end

        try
        set(fo.e,'Startpoint',st.e);       
        [curveFit5,goodness5,probs5] = fit(x2,y2,ft.e,fo.e);
        catch
            
             %Use dummy values 
             set(fo.e,'Startpoint',st.e);       
             [curveFit5,goodness5,probs5] = fit(dummy_x2,dummy_y2,ft.e,fo.e);
        end

        %% Select best fit  
        Median1= median(Output_SSE.a);
        Median2= median(Output_SSE.b);
        Median3= median(Output_SSE.c);
        Median4= median(Output_SSE.d);
        Median5= median(Output_SSE.e);

        TEST2_1 = Median1/Median2;
        TEST2_2 = Median2/Median3;
        TEST2_3 = Median3/Median4;
        TEST2_4 = Median4/Median5;


         if     Median1<5&&TEST2_1<4
                Coef=coeffvalues(curveFit1);
                SSE=goodness1.sse;
                adjrsquare=goodness1.adjrsquare;
                Gaus= 1;
         elseif Median2<5&&TEST2_2<4
                Coef=coeffvalues(curveFit2);
                SSE=goodness2.sse;
                adjrsquare=goodness2.adjrsquare;
                Gaus= 2;
         elseif Median3<5&&TEST2_3<4
                Coef=coeffvalues(curveFit3);
                SSE=goodness3.sse;
                adjrsquare=goodness3.adjrsquare;
                Gaus= 3;
         elseif Median4<5&&TEST2_4<4
                Coef=coeffvalues(curveFit4);
                SSE=goodness4.sse;
                adjrsquare=goodness4.adjrsquare;
                Gaus= 4;
         elseif Median5<2&&TEST2_4>4
                Coef=coeffvalues(curveFit5);
                SSE=goodness5.sse;
                adjrsquare=goodness5.adjrsquare;
                Gaus= 5;
                
         else Coef=9999;
                SSE=9999;
                adjrsquare=9999;
                Gaus= 0;
         end
         No_Gaus(1,Prot_nr)=Gaus;

        %% Write output
        if Coef==9999;
       else
            Num_Gaus=(numel(Coef))/3;
            Gaus = reshape(Coef,3,Num_Gaus);
            Values_Considered_for_analysis=0;
            Values_Not_Considered_for_analysis=0;
            for i=1:Num_Gaus                
               Height = Gaus(1,i);
               Center =Gaus(2,i)-5;  %5 is because that are added 5 points before chrom
               Width =Gaus(3,i);
               Size_of_complex=SEC_fit(1)*Center+SEC_fit(2);
               %Test guassian properties
               if ((Height>=0.5) && (Width>=1) && (Center>Start_Fr) && (Center<End_Fr) && (~isnan(Sig(round(Center+10)))))
                    %write out Gaussians for further analysis
                    Values_Considered_for_analysis=Values_Considered_for_analysis+1; %Records the number of guassian which will outputed 
                    %For Gausians
                    fileName1A = strcat(mat2str(Prot_nr),'_',mat2str(i),'_',Experimental_channel,'_OutputGaus','.csv'); %set the output file
                    fid= fopen(fileName1A,'at'); % create the output file
                    fprintf (fid,'%6.4f,%6.4f,%s,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,\n',...
                    Protein_number(Prot_nr), num_val_MvsL(Prot_nr),txt_MvsL{Prot_nr+1}, Height, Center, Width, SSE, adjrsquare, (round(Size_of_complex/10)*10));
                    %For Chromatograms
                    fileName2A = strcat(mat2str(Prot_nr),'_',mat2str(i),'_',Experimental_channel,'_Output_Chromatograms','.csv');
                    fid2A = fopen(fileName2A,'at');
                    fprintf(fid2A,'%6.4f,%6.4f,%s,',Protein_number(Prot_nr), num_val_MvsL(Prot_nr), txt_MvsL{Prot_nr+1});
                    fprintf(fid2A,'%6.4g,', Smo_Out);
                    fprintf(fid2A,'\n');
                    fclose(fid);
                    movefile(fileName1A, 'OutputGaus');
                    fclose(fid2A);
                    movefile(fileName2A, 'Output_Chromatograms');
               elseif ((Height<0.5) | (Width<1) | (Center<=Start_Fr) | (Center>=End_Fr) |(isnan(Sig(round(Center)+10)))) 
                    %write out Gaussians excluded from further analysis
                    Values_Not_Considered_for_analysis=Values_Not_Considered_for_analysis+1; %Records the number of guassian which will outputed
                    %For Gausians
                    fileName1B = strcat(mat2str(Prot_nr),'_',mat2str(i),'_',Experimental_channel,'_OutputGaus_filtered_out','.csv'); %set the output file
                    fid= fopen(fileName1B,'at'); % create the output file
                    fprintf (fid,'%6.4f,%6.4f,%s,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,\n',...
                    Protein_number(Prot_nr), num_val_MvsL(Prot_nr),txt_MvsL{Prot_nr+1}, Height, Center, Width, SSE, adjrsquare, (round(Size_of_complex/10)*10));
                    %For Chromatograms
                    fileName2B = strcat(mat2str(Prot_nr),'_',mat2str(i),'_',Experimental_channel,'_Output_Chromatograms_filtered_out','.csv');
                    fid2B = fopen(fileName2B,'at');
                    fprintf(fid2B,'%6.4f,%6.4f,%s,',Protein_number(Prot_nr), num_val_MvsL(Prot_nr), txt_MvsL{Prot_nr+1});
                    fprintf(fid2B,'%6.4g,', Smo_Out);
                    fprintf(fid2B,'\n');
                    fclose(fid);
                    movefile(fileName1B, 'OutputGaus_filtered_out');
                    fclose(fid2B);
                    movefile(fileName2B, 'Output_Chromatograms_filtered_out');   
                end
            end
            Gaussians_used_in_analysis_counter(Prot_nr)= Values_Considered_for_analysis;
            Gaussians_excluded_from_analysis_counter(Prot_nr)= Values_Not_Considered_for_analysis;
       end
       end
    end
    
catch

%If error detected write to file
cd('Error_check');
fileName_error = strcat(mat2str(Prot_nr),'_',Experimental_channel,'_error','.csv');
fid_error = fopen(fileName_error,'at');  
fprintf (fid_error,'%s,%s,%s,\n','Protein number','Replicate','Error in Protein'); %Write Header
fprintf (fid_error,'%6.4f,%6.4f,%s,\n',Protein_number(Prot_nr), num_val_MvsL(Prot_nr),txt_MvsL{Prot_nr+1});    %Error log if code fails
fclose(fid_error);
cd('../')

end
end



%% For summary of the number of Gausians
Mean_No_Quant_String=mean(No_Quant_String);
Mean_No_After_adding_one_missing_data= mean(No_After_adding_one_missing_data);
%remove entries equal to zero in array to determine the average number
%of datapoints with values
No_After_filtering(No_After_filtering==0)=[];
Mean_No_After_filtering=mean(No_After_filtering);

%create matrix to count
No_Gaus_0_matrix=(No_Gaus==0);
No_Gaus_1_matrix=(No_Gaus==1);
No_Gaus_2_matrix=(No_Gaus==2);
No_Gaus_3_matrix=(No_Gaus==3);
No_Gaus_4_matrix=(No_Gaus==4);
No_Gaus_5_matrix=(No_Gaus==5);
Try_Fit_matrix=(Try_Fit==1);

%Count if guassian was find AND was attempted
No_Gaus_0=sum(No_Gaus_0_matrix & Try_Fit_matrix);
No_Gaus_1=sum(No_Gaus_1_matrix & Try_Fit_matrix);
No_Gaus_2=sum(No_Gaus_2_matrix & Try_Fit_matrix);
No_Gaus_3=sum(No_Gaus_3_matrix & Try_Fit_matrix);
No_Gaus_4=sum(No_Gaus_4_matrix & Try_Fit_matrix);
No_Gaus_5=sum(No_Gaus_5_matrix & Try_Fit_matrix);
No_try_fit=sum(Try_Fit_matrix);

fileName3 = strcat(Experimental_channel,'_','Summary_Gausians_identifed.csv');
fid3 = fopen(fileName3,'w');
fprintf (fid3,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n',...
'Number_of_proteins','Mean_No_Quant_String', 'Mean_No_After_adding_one_missing_data',...
'Mean_No_After_filtering', '0 Gausian', '1 Gausian', '2 Gausians',...
'3 Gausians', '4 Gausians', '5 Gausians', 'No_try_fit');                      %Write Header

fprintf (fid3,'%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f\n',...
Proteins, Mean_No_Quant_String, Mean_No_After_adding_one_missing_data,...
Mean_No_After_filtering, No_Gaus_0, No_Gaus_1, No_Gaus_2, No_Gaus_3,...
No_Gaus_4, No_Gaus_5, No_try_fit);
fclose(fid3);

%% write out proteins with Gaus equal to zero but that contains five consecuative measurements
fileName_no_fit = strcat(Experimental_channel,'_Proteins_not_fitted_to_gaussian.csv');
fid5 = fopen(fileName_no_fit,'w');
for counter=1:Proteins
    if (No_Gaus_0_matrix(counter)== 1 && Try_Fit_matrix(counter) == 1)
    fprintf(fid5,'%6.4f,%s,%6.4f,', counter,txt_MvsL{(counter+1)},num_val_to_test(counter,1));
    fprintf(fid5,'%6.4g,', num_val_to_test(counter, 2:Fractions));
    fprintf(fid5,'\n');
    end
end
fclose(fid5);

%% For summary of the number of Gausians for individual proteins

Protein_names=txt_MvsL(2:Proteins+1,1);
Protein_Gaus= No_Gaus(1:Proteins);
Protein_Gaus=transpose(Protein_Gaus);
Protein_Gaus=arrayfun(@num2str, Protein_Gaus, 'Uniform', false);
replicate_num_array=arrayfun(@num2str,[num_val_MvsL(:,1)],'Uniform', false);
Gaussians_used_in_analysis_counter1=transpose(Gaussians_used_in_analysis_counter);
Gaussians_used_in_analysis_counter2=arrayfun(@num2str, Gaussians_used_in_analysis_counter1, 'Uniform', false);
Gaussians_not_used_in_analysis_counter=transpose(Gaussians_excluded_from_analysis_counter);
Gaussians_not_used_in_analysis_counter=arrayfun(@num2str, Gaussians_not_used_in_analysis_counter, 'Uniform', false);
A1= [cellfun(@num2str, num2cell(Protein_number'), 'UniformOutput' , false ), Protein_names, replicate_num_array, Protein_Gaus, Gaussians_used_in_analysis_counter2, Gaussians_not_used_in_analysis_counter];

%Write out Guassian information
fileName4 = strcat(Experimental_channel,'_','Summary_Gausians_for_individual_proteins.csv');
fid4 = fopen(fileName4,'w');
fprintf (fid4,'%s,%s,%s,%s,%s,%s\n',...
'Protein_number', 'Gene_name', 'Replicate', 'Number_of_Gausians_detected','Number_of_Gausians_within_defined_boundaries','Number_of_Gausians_filtered');               %Write Header
for i=1:size(A1)
    fprintf(fid4, '%s,%s,%s,%s,%s,%s\n', A1{i,:});
end
fclose(fid4);

%% combine csv output together in a single file

%% OutputGaus files
dirData1 = dir('OutputGaus');      %# Get directory contents
dirData1 = dirData1(~[dirData1.isdir]);  %# Use only the file data
OutputGaus_fileNames = {dirData1.name};           %# Get file names

ExpName1 = strcat('^(\d+)\_(\d+)\_',Experimental_channel,'_OutputGaus.csv');
OutputGaus_fileData = regexp(OutputGaus_fileNames,ExpName1,'tokens');  %# Find tokens
index1 = ~cellfun('isempty',OutputGaus_fileData);        %# Find index of matches
OutputGaus_fileData = [OutputGaus_fileData{index1}];                %# Remove non-matches
OutputGaus_fileData = vertcat(OutputGaus_fileData{:});             %# Format token data
OutputGaus_fileNames = OutputGaus_fileNames(index1);

%sorting OutputGaus_file so in correct numerical order
nFiles1 = size(OutputGaus_fileData,1);              %# Number of files matching format
OutputGaus_fileData = str2double(OutputGaus_fileData);        %# Convert from strings to numbers
OutputGaus_fileData = [OutputGaus_fileData zeros(nFiles1,1)];  %# Add a zero column
OutputGaus_fileData = [OutputGaus_fileData(:,1) datenum(OutputGaus_fileData(:,2:end))];  %# Format dates

[OutputGaus_fileData,index1] = sortrows(OutputGaus_fileData,1:2);  %# Sort numeric values
OutputGaus_fileNames =  OutputGaus_fileNames(index1);               %# Apply sort to file names

Combined_OutputGaus_length = length(OutputGaus_fileNames);
Combined_processed_data=cell(Combined_OutputGaus_length,10);
cd('OutputGaus') 

%Read in processed datafiles
for iii = 1:Combined_OutputGaus_length 
    %load file of interest
    fileName6 = strcat(OutputGaus_fileNames(iii));
    File_to_be_read = fileName6{1};
    %import data files
    f = fopen (File_to_be_read);
    Processed_data = textscan(f, '%n %n %s %n %n %n %n %n %n', 'Delimiter', ',');
    fclose(f);
    %add Gaus index number
    Gaus_index_number= iii;
    %combined index number and fitted data
    Processed_data = [Gaus_index_number, Processed_data{:}];
    Combined_processed_data(iii,:)=Processed_data(1,:);    
end

cd('../')

%Write out Combined process data to csv file
fileName5 = strcat(Experimental_channel,'_','Combined_OutputGaus.csv');
fid_combined_Gaus = fopen(fileName5,'w');
fprintf (fid_combined_Gaus,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n',... %header for OutputGaus output
'Guassian index number','Protein_number','Replicate','Protein name', 'Height', 'Center', 'Width', 'SSE', 'adjrsquare','Complex size'); %Write Header
for iv = 1:Combined_OutputGaus_length 
    fprintf(fid_combined_Gaus,'%6.4f,%6.4f,%6.4f,',Combined_processed_data{iv,1:3}); %Write out the index information
    Name_to_write_out=Combined_processed_data{iv,4}; %Write out to new variable, note this is done for consistency as importing seems to generate a nested cell for the other lists
    fprintf(fid_combined_Gaus,'%s,',Name_to_write_out(:)); %Write out the protein name
    fprintf(fid_combined_Gaus,'%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,\n',Combined_processed_data{iv,5:10}); %Gaussian fitting information
end
fclose(fid_combined_Gaus);


%% Combine Output_Chromatograms
dirData2 = dir('Output_Chromatograms');      %# Get directory contents
dirData2 = dirData2(~[dirData2.isdir]);      %# Use only the file data
Output_Chromatograms_fileNames = {dirData2.name};           %# Get file names

ExpName2 = strcat('^(\d+)\_(\d+)\_',Experimental_channel,'_Output_Chromatograms.csv');
Output_Chromatograms_fileData = regexp(Output_Chromatograms_fileNames,ExpName2,'tokens');  %# Find tokens
index2 = ~cellfun('isempty',Output_Chromatograms_fileData);        %# Find index of matches
Output_Chromatograms_fileData = [Output_Chromatograms_fileData{index2}];                %# Remove non-matches
Output_Chromatograms_fileData = vertcat(Output_Chromatograms_fileData{:});             %# Format token data
Output_Chromatograms_fileNames = Output_Chromatograms_fileNames(index2);

%sorting OutputGaus_file so in correct numerical order
nFiles2 = size(Output_Chromatograms_fileData,1);              %# Number of files matching format
Output_Chromatograms_fileData = str2double(Output_Chromatograms_fileData);        %# Convert from strings to numbers
Output_Chromatograms_fileData = [Output_Chromatograms_fileData zeros(nFiles2,1)];  %# Add a zero column (for the seconds)
Output_Chromatograms_fileData = [Output_Chromatograms_fileData(:,1) datenum(Output_Chromatograms_fileData(:,2:end))];  %# Format dates

[Output_Chromatograms_fileData,index2] = sortrows(Output_Chromatograms_fileData,1:3);  %# Sort numeric values
Output_Chromatograms_fileNames =  Output_Chromatograms_fileNames(index2);               %# Apply sort to file names

Combined_Output_Chromatograms_length = length(Output_Chromatograms_fileNames);
Combined_processed_chromatogram_data=cell(Combined_Output_Chromatograms_length,69);
cd('Output_Chromatograms');

for v = 1:Combined_Output_Chromatograms_length 
    %load file of interest
    fileName8 = strcat(Output_Chromatograms_fileNames(v));
    File_to_be_read = fileName8{1};
    %import data files
    f_chromatogram = fopen (File_to_be_read);
    Processed_Chromatogram_data = textscan(f_chromatogram, '%n %n %s %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n', 'Delimiter', ',');
    fclose(f_chromatogram);
    %add Gaus index number
    Gaus_index_number= v;
    %combined index number and fitted data
    Processed_Chromatogram_data = [Gaus_index_number, Processed_Chromatogram_data];
    %Combine data together
    Combined_processed_chromatogram_data(v,:)=Processed_Chromatogram_data(1,:);    
end

cd('../')

%Write out combined chromatogram data to csv file
dimension_of_processed_chromatogram=size(Combined_processed_chromatogram_data);
fileName7 = strcat(Experimental_channel,'_','Combined_Chromatograms.csv');
fid_combined_Chromatogram = fopen(fileName7,'w');
for iv = 1:Combined_Output_Chromatograms_length
    fprintf(fid_combined_Chromatogram,'%6.4f,%6.4f,%6.4f,',Combined_processed_chromatogram_data{iv,1:3}); %Write out the index information
    Name_to_write_out=Combined_processed_chromatogram_data{iv,4}; %To deal with the nested cell, write out to new variable
    fprintf(fid_combined_Chromatogram,'%s,',Name_to_write_out{:}); %Write out protein name
    fprintf(fid_combined_Chromatogram,'%6.4g,',Combined_processed_chromatogram_data{iv,(5:dimension_of_processed_chromatogram(2))}); %Chromatogram information
    fprintf(fid_combined_Chromatogram,'\n');
end
fclose(fid_combined_Chromatogram);


%% OutputGaus files filtered out
dirData1 = dir('OutputGaus_filtered_out');      %# Get directory contents
dirData1 = dirData1(~[dirData1.isdir]);  %# Use only the file data
OutputGaus_fileNames = {dirData1.name};           %# Get file names

ExpName1 = strcat('^(\d+)\_(\d+)\_',Experimental_channel,'_OutputGaus_filtered_out.csv');
OutputGaus_fileData = regexp(OutputGaus_fileNames,ExpName1,'tokens');  %# Find tokens
index1 = ~cellfun('isempty',OutputGaus_fileData);        %# Find index of matches
OutputGaus_fileData = [OutputGaus_fileData{index1}];                %# Remove non-matches
OutputGaus_fileData = vertcat(OutputGaus_fileData{:});             %# Format token data
OutputGaus_fileNames = OutputGaus_fileNames(index1);

%sorting OutputGaus_file so in correct numerical order
nFiles1 = size(OutputGaus_fileData,1);              %# Number of files matching format
OutputGaus_fileData = str2double(OutputGaus_fileData);        %# Convert from strings to numbers
OutputGaus_fileData = [OutputGaus_fileData zeros(nFiles1,1)];  %# Add a zero column
OutputGaus_fileData = [OutputGaus_fileData(:,1) datenum(OutputGaus_fileData(:,2:end))];  %# Format dates

[OutputGaus_fileData,index1] = sortrows(OutputGaus_fileData,1:2);  %# Sort numeric values
OutputGaus_fileNames =  OutputGaus_fileNames(index1);               %# Apply sort to file names

Combined_OutputGaus_filtered_length = length(OutputGaus_fileNames);
Combined_processed_Filtered_data=cell(Combined_OutputGaus_filtered_length,10);
cd('OutputGaus_filtered_out') 

for iii = 1:Combined_OutputGaus_filtered_length 
    %load file of interest
    fileName6 = strcat(OutputGaus_fileNames(iii));
    File_to_be_read = fileName6{1};
    %import data files
    f = fopen (File_to_be_read);
    Processed_data = textscan(f, '%n %n %s %n %n %n %n %n %n', 'Delimiter', ',');
    fclose(f);
    %add Gaus index number
    Gaus_index_number= iii;
    %combined index number and fitted data
    Processed_data = [Gaus_index_number, Processed_data];
    Combined_processed_Filtered_data(iii,:)=Processed_data(1,:);    
end

cd('../')

%Write out Combined process data to csv file
fileName5 = strcat(Experimental_channel,'_','Combined_OutputGaus_filtered_out.csv');
fid_combined_Gaus = fopen(fileName5,'w');
fprintf (fid_combined_Gaus,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n',... %header for OutputGaus output
'Guassian index number','Protein_number','Replicate','Protein name', 'Height', 'Center', 'Width', 'SSE', 'adjrsquare','Complex size'); %Write Header
for iv = 1:Combined_OutputGaus_filtered_length 
    fprintf(fid_combined_Gaus,'%6.4f,%6.4f,%6.4f,',Combined_processed_Filtered_data{iv,1:3}); %Write out the index information
    Name_to_write_out=Combined_processed_Filtered_data{iv,4};
    fprintf(fid_combined_Gaus,'%s,',Name_to_write_out{:}); %Write out the protein name
    fprintf(fid_combined_Gaus,'%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,%6.4f,\n',Combined_processed_Filtered_data{iv,5:10}); %Gaussian fitting information
end
fclose(fid_combined_Gaus);


%% Combine Output_Chromatograms of Gaussians filtered out
dirData2 = dir('Output_Chromatograms_filtered_out');      %# Get directory contents
dirData2 = dirData2(~[dirData2.isdir]);      %# Use only the file data
Output_Chromatograms_fileNames = {dirData2.name};           %# Get file names

ExpName2 = strcat('^(\d+)\_(\d+)\_',Experimental_channel,'_Output_Chromatograms_filtered_out.csv');
Output_Chromatograms_fileData = regexp(Output_Chromatograms_fileNames,ExpName2,'tokens');  %# Find tokens
index2 = ~cellfun('isempty',Output_Chromatograms_fileData);        %# Find index of matches
Output_Chromatograms_fileData = [Output_Chromatograms_fileData{index2}];                %# Remove non-matches
Output_Chromatograms_fileData = vertcat(Output_Chromatograms_fileData{:});             %# Format token data
Output_Chromatograms_fileNames = Output_Chromatograms_fileNames(index2);

%sorting OutputGaus_file so in correct numerical order
nFiles2 = size(Output_Chromatograms_fileData,1);              %# Number of files matching format
Output_Chromatograms_fileData = str2double(Output_Chromatograms_fileData);        %# Convert from strings to numbers
Output_Chromatograms_fileData = [Output_Chromatograms_fileData zeros(nFiles2,1)];  %# Add a zero column (for the seconds)
Output_Chromatograms_fileData = [Output_Chromatograms_fileData(:,1) datenum(Output_Chromatograms_fileData(:,2:end))];  %# Format dates

[Output_Chromatograms_fileData,index2] = sortrows(Output_Chromatograms_fileData,1:3);  %# Sort numeric values
Output_Chromatograms_fileNames =  Output_Chromatograms_fileNames(index2);               %# Apply sort to file names

Combined_Output_Chromatograms_filter_length = length(Output_Chromatograms_fileNames);
Combined_processed_Chromatograms_filtered_data=cell(Combined_Output_Chromatograms_filter_length,69);
cd('Output_Chromatograms_filtered_out');

for v = 1:Combined_Output_Chromatograms_filter_length 
    %load file of interest
    fileName8 = strcat(Output_Chromatograms_fileNames(v));
    File_to_be_read = fileName8{1};
    %import data files
    f_Chromatogram = fopen (File_to_be_read);
    Processed_Chromatogram_data = textscan(f_Chromatogram,'%n %n %s %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n %n', 'Delimiter', ',');
    fclose(f_Chromatogram);
    %add Gaus index number
    Gaus_index_number= v;
    %combined index number and fitted data
    Processed_Chromatogram_data = [Gaus_index_number, Processed_Chromatogram_data];
    %Combine data together
    Combined_processed_Chromatograms_filtered_data(v,:)=Processed_Chromatogram_data(1,:);    
end

cd('../')

%Write out combined chromatogram data to csv file
dimension_of_processed_chromatogram=size(Combined_processed_Chromatograms_filtered_data);
fileName7 = strcat(Experimental_channel,'_','Combined_Chromatograms_filtered_out.csv');
fid_combined_Chromatogram = fopen(fileName7,'w');
for iv = 1:Combined_Output_Chromatograms_filter_length
    fprintf(fid_combined_Chromatogram,'%6.4f,%6.4f,%6.4f,',Combined_processed_Chromatograms_filtered_data{iv,1:3}); %Write out the index information
    Name_to_write_out=Combined_processed_Chromatograms_filtered_data{iv,4}; %To deal with the nested cell, write out to new variable
    fprintf(fid_combined_Chromatogram,'%s,',Name_to_write_out{:}); %Write out protein name
    fprintf(fid_combined_Chromatogram,'%6.4g,',Combined_processed_Chromatograms_filtered_data{iv,(5:dimension_of_processed_chromatogram(2))}); %Chromatogram information
    fprintf(fid_combined_Chromatogram,'\n');
end
fclose(fid_combined_Chromatogram);


%Write list of proteins with Guassian for use for later analysis
checker_counter=1;
Protein_Gaus_double= str2double(Protein_Gaus);
Gaussians_used_counter_double= str2double(Gaussians_used_in_analysis_counter2);
Gaussians_not_used_counter_double= str2double(Gaussians_not_used_in_analysis_counter);
for checker= 1:Proteins
    values=Protein_Gaus_double(checker);
    value_check=values>0;
    if value_check==1
        summerised_protein_number(checker_counter)=checker(1);
        summerised_names{checker_counter}=Protein_names{checker};
        summerised_guas_number(checker_counter)=Protein_Gaus_double(checker);
        summerised_replicate(checker_counter)=num_val_MvsL(checker,1);
        summerised_guas_number_within_boundaries{checker_counter}=Gaussians_used_counter_double(checker);
        summerised_guas_number_filtered{checker_counter}=Gaussians_not_used_counter_double(checker);
        checker_counter=checker_counter+1;
    end
end

total_number_of_proteins_gaus=length(summerised_protein_number);
fileName9 = strcat(Experimental_channel,'_','Summary_Proteins_with_Gausians.csv');
fid_proteins_gaus = fopen(fileName9,'w');
fprintf (fid_proteins_gaus,'%s,%s,%s,%s,%s,%s\n',...
'Protein Number', 'Protein Name','Replicate','Number of Gaussian','Number of Gaussian within Boundaries','Number of Gaussian filtered');%Write Header

for v=1:total_number_of_proteins_gaus
fprintf (fid_proteins_gaus,'%6.4f,%s,%6.4f,%6.4f,%6.4f,%6.4f\n',...
summerised_protein_number(v), summerised_names{v}, summerised_replicate(v),summerised_guas_number(v),summerised_guas_number_within_boundaries{v},summerised_guas_number_filtered{v});
end
fclose(fid_proteins_gaus);
cd('../');

end
    
fclose('all');
toc